==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/PASideEffectTester.h <==
// public class soot.jimple.toolkits.pointer.PASideEffectTester

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 34d800b878a164fc soot_jimple_toolkits_pointer_PASideEffectTester

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_PASideEffectTester_H_
#define _JC_soot_jimple_toolkits_pointer_PASideEffectTester_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_soot_Local$object;
struct _jc_soot_PointsToAnalysis$object;
struct _jc_soot_PointsToSet$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_toolkits_pointer_RWSet$object;
struct _jc_soot_jimple_toolkits_pointer_SideEffectAnalysis$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_refs	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$refs	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$nonrefs	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vmethods	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtable	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$newMethod$b27d7d51d7418014(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_soot_SootMethod$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$reachingObjects$13399f75330ed05c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *);
extern struct _jc_soot_jimple_toolkits_pointer_RWSet$object *_jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$readSet$4c18a82384a7b887(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$unitCanReadFrom$0db80b916700aa7c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$unitCanWriteTo$e50298a7ad8b028b(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$valueTouchesRWSet$1a15365a9d19702f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_soot_jimple_toolkits_pointer_RWSet$object *_jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$writeSet$2b87ff894c548eb1(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$newMethod$b27d7d51d7418014;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$reachingObjects$13399f75330ed05c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$readSet$4c18a82384a7b887;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$unitCanReadFrom$0db80b916700aa7c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$unitCanWriteTo$e50298a7ad8b028b;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$valueTouchesRWSet$1a15365a9d19702f;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$writeSet$2b87ff894c548eb1;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vmethods {
	void	(*newMethod$b27d7d51d7418014)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_soot_SootMethod$object *);
	struct _jc_object	*(*reachingObjects$13399f75330ed05c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *);
	struct _jc_soot_jimple_toolkits_pointer_RWSet$object	*(*readSet$4c18a82384a7b887)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *);
	jboolean	(*unitCanReadFrom$0db80b916700aa7c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *, struct _jc_object *);
	jboolean	(*unitCanWriteTo$e50298a7ad8b028b)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *, struct _jc_object *);
	jboolean	(*valueTouchesRWSet$1a15365a9d19702f)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_soot_jimple_toolkits_pointer_RWSet$object	*(*writeSet$2b87ff894c548eb1)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vmethods	soot_jimple_toolkits_pointer_PASideEffectTester;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_refs {
	struct _jc_object	*pa;
	struct _jc_soot_jimple_toolkits_pointer_SideEffectAnalysis$object	*sea;
	struct _jc_java_util_HashMap$object	*unitToRead;
	struct _jc_java_util_HashMap$object	*unitToWrite;
	struct _jc_java_util_HashMap$object	*localToReachingObjects;
	struct _jc_soot_SootMethod$object	*currentMethod;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$refs {
    _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_refs	soot_jimple_toolkits_pointer_PASideEffectTester;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_nonrefs	soot_jimple_toolkits_pointer_PASideEffectTester;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object {
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype _jc_soot_jimple_toolkits_pointer_PASideEffectTester$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_PASideEffectTester, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_PASideEffectTester$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_PASideEffectTester_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/PASideEffectTester.h <==
// public class soot.jimple.toolkits.pointer.PASideEffectTester

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 34d800b878a164fc soot_jimple_toolkits_pointer_PASideEffectTester

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_PASideEffectTester_H_
#define _JC_soot_jimple_toolkits_pointer_PASideEffectTester_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_soot_Local$object;
struct _jc_soot_PointsToAnalysis$object;
struct _jc_soot_PointsToSet$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_toolkits_pointer_RWSet$object;
struct _jc_soot_jimple_toolkits_pointer_SideEffectAnalysis$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_refs	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$refs	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$nonrefs	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vmethods	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtable	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$newMethod$b27d7d51d7418014(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$reachingObjects$13399f75330ed05c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_RWSet$object *_jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$readSet$4c18a82384a7b887(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$unitCanReadFrom$0db80b916700aa7c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$unitCanWriteTo$e50298a7ad8b028b(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$valueTouchesRWSet$1a15365a9d19702f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_RWSet$object *_jc_soot_jimple_toolkits_pointer_PASideEffectTester$method$writeSet$2b87ff894c548eb1(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$newMethod$b27d7d51d7418014;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$reachingObjects$13399f75330ed05c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$readSet$4c18a82384a7b887;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$unitCanReadFrom$0db80b916700aa7c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$unitCanWriteTo$e50298a7ad8b028b;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$valueTouchesRWSet$1a15365a9d19702f;
extern _jc_method _jc_soot_jimple_toolkits_pointer_PASideEffectTester$method_info$writeSet$2b87ff894c548eb1;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vmethods {
	void	(*newMethod$b27d7d51d7418014)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*reachingObjects$13399f75330ed05c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_toolkits_pointer_RWSet$object	*(*readSet$4c18a82384a7b887)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*unitCanReadFrom$0db80b916700aa7c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*unitCanWriteTo$e50298a7ad8b028b)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*valueTouchesRWSet$1a15365a9d19702f)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_toolkits_pointer_RWSet$object	*(*writeSet$2b87ff894c548eb1)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vmethods	soot_jimple_toolkits_pointer_PASideEffectTester;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_refs {
	struct _jc_object	*pa;
	struct _jc_soot_jimple_toolkits_pointer_SideEffectAnalysis$object	*sea;
	struct _jc_java_util_HashMap$object	*unitToRead;
	struct _jc_java_util_HashMap$object	*unitToWrite;
	struct _jc_java_util_HashMap$object	*localToReachingObjects;
	struct _jc_soot_SootMethod$object	*currentMethod;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$refs {
    _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_refs	soot_jimple_toolkits_pointer_PASideEffectTester;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_PASideEffectTester$sub_nonrefs	soot_jimple_toolkits_pointer_PASideEffectTester;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_PASideEffectTester$object {
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_PASideEffectTester$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_PASideEffectTester$vtype _jc_soot_jimple_toolkits_pointer_PASideEffectTester$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_PASideEffectTester, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_PASideEffectTester$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_PASideEffectTester_H_ */
